# 0.1.3 / 2019-03-30

  * Fix #3 -- verto.dim2 Pipeline wrapped into PcaMinka class

# 0.1.2 / 2019-03-30

  * Fix #1 -- "__repr__" and "__str__" method of verto.dim3.PcaEv aligned

# 0.1.1 / 2019-03-29

  * modules added in setup.py

# 0.1.0 / 2019-03-25

  * Initial upload

# 0.0.0 / 2018-12-21

  * Pre-release development phase started
